@@ -1,11 +1,10 @@
 ;; -*- no-byte-compile: t; lexical-binding: nil -*-
-(define-package "srfi" "0.3"
+(define-package "srfi" "20251012.351"
   "Scheme Requests for Implementation browser."
-  '((emacs  "25.1")
-    (cl-lib "0.5"))
+  '((emacs "25.1"))
   :url "https://github.com/srfi-explorations/emacs-srfi"
-  :commit "98b8b1f9edd4ce6a05eeef49bed0d1966bd7c528"
-  :revdesc "0.3-0-g98b8b1f9edd4"
+  :commit "c8e72733cd4d919d20c0452311390441cf8b6862"
+  :revdesc "c8e72733cd4d"
   :keywords '("languages" "util")
   :authors '(("Lassi Kortela" . "lassi@lassi.io"))
   :maintainers '(("Lassi Kortela" . "lassi@lassi.io")))
